# UTF-8 encoded Brazilian Portuguese language file for use with Oddmuse
#
# Copyright (c) 2003  Marcelo Toledo <rw@locked.org>.
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: portuguese-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Leitura não permitida: usuário, ip, ou rede está bloqueada.
Could not create %s
Não foi possivel criar %s
Invalid UserName %s: not saved.
Usuário inválido %s: nada salvo.
UserName must be 50 characters or less: not saved
NomeUsuario deve ter 50 caracteres ou menos: nada salvo
This page contains an uploaded file:

XML::RSS is not available on this system.
XML::RSS não existe neste sistema
diff
diferenças
history
história
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

Invalid action parameter %s
Parametro de ação inválido %s
Invalid URL.
URL inválida.
Page name is missing
Falta o nome da página
Page name is too long: %s
Nome de página é muito longo: %s
Invalid Page %s
Página %s invália
Invalid Page %s (must not end with .db)
Página %s inválida (não pode terminar com .db)
Invalid Page %s (must not end with .lck)
Página %s inválida (não pode terminar com .lck)
Page name may not contain space characters: %s
Nome de página não pode conter espaço: %s
Preview:
Prever:
Preview only, not yet saved
Visualização apenas, nada foi salvo
Please go on to %s.
Por favor vá para %s
Could not open %s log file
Não foi possivel abrir o arquivo %s de log
Error was
Erro foi
Note: This error is normal if no changes have been made.
NOTA: Esse erro é normal se nenhuma alteração foi feita.
Could not open old %s log file
Não foi possivel abrir o antigo arquivo %s de log
No updates since %s
Nenhuma atualização desde %s
Updates since %s
Atualizações desde %s
Updates in the last %s days
Atualizações nos últimos %s dias
Updates in the last %s day
Atualizações no último %s dia
for %s only
para %s apenas
List latest change per page only
Mostra só as últimas modificações por página
List all changes
Mostra todas as modificações
List only major changes
Mostra só as modificações maiores
Include minor changes
Inclui também as modificações menores
%s days
%s dias
List later changes
Mostra novas modificações
Filters
Filtros
Username:
Usuário:
Host:

Language:
Língua:
Go!
Ir!
(minor)
(mínima)
rollback

new
novo
from %s
de %s
History of %s
Histórico de %s
Compare
Comparar
Revision %s
Revisão %s
by
por
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Índice de todas as páginas
Wiki Version
Mostrando versão do Wiki
Unlock Wiki
Destravando
Recent Visitors
Visitantes recentes
Password
Senha
Run maintenance
Manutenção
Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Ínicio]
redirected from %s
redirecionado de %s
Click to search for references to this page

Cookie: 

Warning
Atenção
Database is stored in temporary directory %s
Banco de dados é armazenado no diretório temporario %s
%s seconds
%s segundos
The same page on other sites:
A mesma página noutro lado:
EditNearLinks

Last edited
Ultima edição
Edited
Editado
by %s
de %s
(diff)
(diff)
Edit revision %s of this page
Edite a revisão %s desta página
Edit this page
Edite esta página
e

This page is read-only
Esta página é apenas para leitura
View other revisions
Veja outras revisões
View current revision
Veja a versão corrente
View all changes
Veja todas os câmbios
new comment
Comentário novo
Homepage URL:

s
s
Save
Salvar
Preview
Prever
Search:
Busca:
f

Replace:

Validate HTML
Validar HTML
Validate CSS
Validar CSS
Difference (from revision %1 to %2)
Diferença (entre a revisão %1 e %2)
revision %s
revisão %s
current revision
versão corrente
Difference (from prior %s revision)
Diferença (anterior à %s revisão)
major
importante
minor
simples
No diff available.
Nenhum diff disponivel.
Old revision:
Revisão antiga:
Changed:
Alterado:
Removed:
Removido:
Added:
Adicionado:
to
para
Revision %s not available
Revisão %s não disponivel
showing current revision instead
ao invéz mostrando versão corrente
Showing revision %s
Mostrando versão %s
Cannot save a nameless page.
Não se pode salvar uma página sem nome.
Cannot save a page without revision.
Não se pode salvar uma página sem revisão.
Cannot open %s
Não foi possível abrir %s
Cannot write %s
Não foi possível escrever %s
Could not get %s lock
Não foi possível conseguir a trava %s
This operation may take several seconds...
Essa operação pode demorar alguns segundos...
Forced unlock of %s lock.
Trava forcada de %s
No unlock required.
Nenhum destravamento necessário.
%s hours ago
%s horas atras
1 hour ago
1 hora atras
%s minutes ago
%s minutos atras
1 minute ago
1 minuto atras
%s seconds ago
%s segundos atras
1 second ago
1 segundo atras
just now
agora
Editing Denied
Edição não permitida
Editing not allowed: user, ip, or network is blocked.
Edição não permitida: usuário, ip, ou rede está bloqueada.
Contact the wiki administrator for more information.
Contate o administrador do wiki para maiores informações.
The rule %s matched for you.
A regra %s confere para você.
See %s for more information.
Para mais informações, veja %s.
Editing not allowed: %s is read-only.
Edição não permitida: %s is apenas para leitura.
Only administrators can upload files.

Editing revision %s of
Editando revisão %s de
Editing %s
Editando %s
Editing old revision %s.
Editando antiga revisão %s.
Saving this page will replace the latest revision with this text.
Salvando esta página irá substituir a ultima revisão com esse texto.
Summary:
Sumário:
This change is a minor edit.
Esta atualização é miníma.
Replace this file with text.
Escrever texto em vez do archivo presente.
Replace this text with a file.
Usar um archivo em vez do texto presente.
File to upload: 
Archivo à usar: 
Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Sua senha é salva em um cookie, caso esteja ativado no seu navegador. Cookies podem se perder se você conectar de outra maquina, outra conta, ou outro software.
You are currently an administrator on this site.
Você é atualmente um administrador neste site.
You are currently an editor on this site.
Você é atualmente um editor neste site.
You are a normal user on this site.
Você é um usuario normal neste site.
Your password does not match any of the  administrator or editor passwords.
Sua senha não confere com nenhuma dos administradores ou editores.
Password:
Senha:
This site does not use admin or editor passwords.
Este site não usa senhas de administrador ou editor.
This operation is restricted to site editors only...
Essa operação é restrita aos editores do site...
This operation is restricted to administrators only...
Essa operação é restrita aos administradores...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(para %s)
%s pages found.
%s páginas encontradas.
Replaced: %s
Substituído: %s
Search for: %s
Buscar por: %s
View changes for these pages
Ver câmbios para estas págians
Search sites on the %s as well
Estender a busca para os sítios no %s
and
e
or
ou
Fetching results from %s:
Buscando os resultados de %s:
Near pages:
Páginas próximas:
last updated
ultima atualização
Complete Content
Conteúdo completo
The main page is %s.
A página principal é %s.
Comments on this page
Commentários sobre esta página
Editing not allowed for %s.
Edição não permitida para %s.
SampleUndefinedPage
ExemploPaginaNaoDefinida
%s cannot be defined.
%s não pode ser definida.
Sample_Undefined_Page
Exemplo_Pagina_Nao_Definida
[[%s]] cannot be defined.
[[%s]] não pode ser definida.
Only an administrator can create %s.
Só administradores podem criar a página %s.
Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.
Esta página foi editada por outra pessoa %s.
The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.
Se faz favor controle se você  esses câmbios.
Anonymous
Anônimo
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
Não foi possivel pegar a trava para combinar!
you
o que você escreveu
ancestor
o que já estava
other
o que a outra pessoa escreveu
Run Maintenance

Maintenance not done.
Manutenção não concluída.
(Maintenance can only be done once every 12 hours.)
(Manutenção pode ser feita apenas a cada 12 horas.)
Remove the "maintain" file or wait.
Romove o arquivo "manter" ou esperar.
Main lock obtained.
Trava principal obtida.
Expiring keep files and deleting pages marked for deletion
Expirando mantém arquivos e deletando páginas marcadas para deletar
not deleted: 
não deletado: 
deleted
deletado
Moving part of the %s log file.
Movendo parte de %s arquivo de log.
Moving %s log entries.
Movendo %s entrada de log.
Getting page index file for %s.

Main lock released.
Trava principal liberado.
Set or Remove global edit lock
Marque ou Remova trava global de edição
Edit lock created.
Trava de edição criada.
Edit lock removed.
Trava de edição removido.
Set or Remove page edit lock
Marque ou Remova trava de ediçao de páginas
Missing page id to lock/unlock...
Faltando id da página para travar/destravar...
Lock for %s created.
Trava para %s criado.
Lock for %s removed.
Trava para %s removido:
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Muitas conexões de %s
Please do not fetch more than %1 pages in %2 seconds.
Se faz favor não busque mais do que %1 páginas em %2 segundos.
Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists
a página %s também existe
Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist
A página %s não existe
The page %s already exists
A página %s já existe
Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous
Prévio
Next
Próximo
Calendar %s
Calendário para %s
Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s
imagem: %s
Index

Languages:
Línguas:
Show!
Mostrar!
Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

%s returned no data.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None
Nenhum
Type
Tipo
Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers

Referrers

Updating %s

Search term missing.

Static Copy

Back to %s
Voltar para %s
Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:
Nome:
Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.
Esta página não existe.
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.de/exec/obidos/ISBN=%s
alternate
alternativa
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
busca
Blog
Blog
END_OF_TRANSLATION
